MavSec
======

A tool for the creation of JasperGold SVP principle tcl files.

[![Tests](https://github.com/RISCY-Lib/mavsec/actions/workflows/test.yml/badge.svg)](https://github.com/RISCY-Lib/mavsec/actions/workflows/test.yml)
[![PyPI Latest Release](https://img.shields.io/pypi/v/mavsec.svg)](https://pypi.org/project/mavsec/)
[![docs](https://readthedocs.org/projects/mavsec/badge)](https://mavsec.readthedocs.io/en/latest/index.html)

See [Read-The-Docs](https://mavsec.readthedocs.io/en/latest/index.html) for details
